part of 'dip_nav_router.dart';

/// A delegate that is used by the [Router] widget to parse a route information
/// into a configuration of type [DipNavRoute].
class _DipNavParser extends RouteInformationParser<DipNavRoute> {
  /// {@macro flutter_dipnav.DipNavRouter}
  final DipNavRouter _delegate;

  _DipNavParser(this._delegate);

  @override
  Future<DipNavRoute> parseRouteInformation(
      RouteInformation routeInformation) async {
    final location = routeInformation.location;
    if (location == null) {
      return _delegate.initRoute;
    }
    final uri = Uri.parse(location);
    if (uri.pathSegments.isEmpty) {
      return _delegate.initRoute;
    }
    final path = uri.pathSegments.first;
    DipNavRoute? foundRoute;
    for (var route in _delegate.routes) {
      if (route.path == path) {
        foundRoute = route;
        break;
      }
    }
    return foundRoute ?? _delegate.notFoundRoute ?? _delegate.initRoute;
  }

  @override
  RouteInformation restoreRouteInformation(DipNavRoute configuration) {
    return RouteInformation(location: configuration.path);
  }
}
